slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPLinearGetLinearization

Returns the coefficients that define the linearization of a quadratic eigenproblem.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPLinearGetLinearization(PEP pep,PetscReal *alpha,PetscReal *beta)

Not Collective

### Input Parameter

| pep | - polynomial eigenvalue solver

### Output Parameters

| alpha | - the first parameter of the linearization
| beta | - the second parameter of the linearization

### See Also

PEPLinearSetLinearization()

### Level

advanced

### Location

src/pep/impls/linear/linear.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages